@@ -1,14 +1,14 @@
 """
 Type annotations for mgn service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_mgn.literals import ChangeServerLifeCycleStateSourceServerLifecycleState
+    from mypy_boto3_mgn.literals import ChangeServerLifeCycleStateSourceServerLifecycleStateType
 
-    data: ChangeServerLifeCycleStateSourceServerLifecycleState = "CUTOVER"
+    data: ChangeServerLifeCycleStateSourceServerLifecycleStateType = "CUTOVER"
     ```
 """
 import sys
@@ -20,35 +20,35 @@ else:
 
 
 __all__ = (
-    "ChangeServerLifeCycleStateSourceServerLifecycleState",
-    "DataReplicationErrorString",
-    "DataReplicationInitiationStepName",
-    "DataReplicationInitiationStepStatus",
-    "DataReplicationState",
+    "ChangeServerLifeCycleStateSourceServerLifecycleStateType",
+    "DataReplicationErrorStringType",
+    "DataReplicationInitiationStepNameType",
+    "DataReplicationInitiationStepStatusType",
+    "DataReplicationStateType",
     "DescribeJobLogItemsPaginatorName",
     "DescribeJobsPaginatorName",
     "DescribeReplicationConfigurationTemplatesPaginatorName",
     "DescribeSourceServersPaginatorName",
-    "FirstBoot",
-    "InitiatedBy",
-    "JobLogEvent",
-    "JobStatus",
-    "JobType",
-    "LaunchDisposition",
-    "LaunchStatus",
-    "LifeCycleState",
-    "ReplicationConfigurationDataPlaneRouting",
-    "ReplicationConfigurationDefaultLargeStagingDiskType",
-    "ReplicationConfigurationEbsEncryption",
-    "ReplicationConfigurationReplicatedDiskStagingDiskType",
-    "TargetInstanceTypeRightSizingMethod",
+    "FirstBootType",
+    "InitiatedByType",
+    "JobLogEventType",
+    "JobStatusType",
+    "JobTypeType",
+    "LaunchDispositionType",
+    "LaunchStatusType",
+    "LifeCycleStateType",
+    "ReplicationConfigurationDataPlaneRoutingType",
+    "ReplicationConfigurationDefaultLargeStagingDiskTypeType",
+    "ReplicationConfigurationEbsEncryptionType",
+    "ReplicationConfigurationReplicatedDiskStagingDiskTypeType",
+    "TargetInstanceTypeRightSizingMethodType",
 )
 
 
-ChangeServerLifeCycleStateSourceServerLifecycleState = Literal[
+ChangeServerLifeCycleStateSourceServerLifecycleStateType = Literal[
     "CUTOVER", "READY_FOR_CUTOVER", "READY_FOR_TEST"
 ]
-DataReplicationErrorString = Literal[
+DataReplicationErrorStringType = Literal[
     "AGENT_NOT_SEEN",
     "FAILED_TO_ATTACH_STAGING_DISKS",
     "FAILED_TO_AUTHENTICATE_WITH_SERVICE",
@@ -64,7 +64,7 @@ DataReplicationErrorString = Literal[
     "SNAPSHOTS_FAILURE",
     "UNSTABLE_NETWORK",
 ]
-DataReplicationInitiationStepName = Literal[
+DataReplicationInitiationStepNameType = Literal[
     "ATTACH_STAGING_DISKS",
     "AUTHENTICATE_WITH_SERVICE",
     "BOOT_REPLICATION_SERVER",
@@ -77,10 +77,10 @@ DataReplicationInitiationStepName = Literal[
     "START_DATA_TRANSFER",
     "WAIT",
 ]
-DataReplicationInitiationStepStatus = Literal[
+DataReplicationInitiationStepStatusType = Literal[
     "FAILED", "IN_PROGRESS", "NOT_STARTED", "SKIPPED", "SUCCEEDED"
 ]
-DataReplicationState = Literal[
+DataReplicationStateType = Literal[
     "BACKLOG",
     "CONTINUOUS",
     "CREATING_SNAPSHOT",
@@ -98,9 +98,9 @@ DescribeReplicationConfigurationTemplatesPaginatorName = Literal[
     "describe_replication_configuration_templates"
 ]
 DescribeSourceServersPaginatorName = Literal["describe_source_servers"]
-FirstBoot = Literal["STOPPED", "SUCCEEDED", "UNKNOWN", "WAITING"]
-InitiatedBy = Literal["DIAGNOSTIC", "START_CUTOVER", "START_TEST", "TERMINATE"]
-JobLogEvent = Literal[
+FirstBootType = Literal["STOPPED", "SUCCEEDED", "UNKNOWN", "WAITING"]
+InitiatedByType = Literal["DIAGNOSTIC", "START_CUTOVER", "START_TEST", "TERMINATE"]
+JobLogEventType = Literal[
     "CLEANUP_END",
     "CLEANUP_FAIL",
     "CLEANUP_START",
@@ -118,11 +118,11 @@ JobLogEvent = Literal[
     "SNAPSHOT_START",
     "USING_PREVIOUS_SNAPSHOT",
 ]
-JobStatus = Literal["COMPLETED", "PENDING", "STARTED"]
-JobType = Literal["LAUNCH", "TERMINATE"]
-LaunchDisposition = Literal["STARTED", "STOPPED"]
-LaunchStatus = Literal["FAILED", "IN_PROGRESS", "LAUNCHED", "PENDING", "TERMINATED"]
-LifeCycleState = Literal[
+JobStatusType = Literal["COMPLETED", "PENDING", "STARTED"]
+JobTypeType = Literal["LAUNCH", "TERMINATE"]
+LaunchDispositionType = Literal["STARTED", "STOPPED"]
+LaunchStatusType = Literal["FAILED", "IN_PROGRESS", "LAUNCHED", "PENDING", "TERMINATED"]
+LifeCycleStateType = Literal[
     "CUTOVER",
     "CUTTING_OVER",
     "DISCONNECTED",
@@ -132,10 +132,10 @@ LifeCycleState = Literal[
     "STOPPED",
     "TESTING",
 ]
-ReplicationConfigurationDataPlaneRouting = Literal["PRIVATE_IP", "PUBLIC_IP"]
-ReplicationConfigurationDefaultLargeStagingDiskType = Literal["GP2", "ST1"]
-ReplicationConfigurationEbsEncryption = Literal["CUSTOM", "DEFAULT", "NONE"]
-ReplicationConfigurationReplicatedDiskStagingDiskType = Literal[
+ReplicationConfigurationDataPlaneRoutingType = Literal["PRIVATE_IP", "PUBLIC_IP"]
+ReplicationConfigurationDefaultLargeStagingDiskTypeType = Literal["GP2", "ST1"]
+ReplicationConfigurationEbsEncryptionType = Literal["CUSTOM", "DEFAULT", "NONE"]
+ReplicationConfigurationReplicatedDiskStagingDiskTypeType = Literal[
     "AUTO", "GP2", "IO1", "SC1", "ST1", "STANDARD"
 ]
-TargetInstanceTypeRightSizingMethod = Literal["BASIC", "NONE"]
+TargetInstanceTypeRightSizingMethodType = Literal["BASIC", "NONE"]
